==> eea.mediacentre-4.3.zip: eea.mediacentre-4.3/src/eea/mediacentre/browser/provider.py <==
""" Provider
"""
from zope.component import queryAdapter
from eea.mediacentre.interfaces import IMediaProvider
from eea.mediacentre.interfaces import IMediaDisplayInfo
from p4a.video.interfaces import IMediaPlayer

class MediaContainerVideos(object):
    """ Media Container Videos
    """

    def __init__(self, context, request):
        self.context = context
        self.reqeust = request

    def media_items(self, media_type):
        """ Returns dicts of all media items available.
            media_type arg is a string, e.g. 'video'
        """

        provider = IMediaProvider(self.context)
        provider.media_type = media_type

        items = []
        for mfile in provider.media_items:
            mime_type = mfile.get_content_type()
            media_info = queryAdapter(mfile, IMediaDisplayInfo, mime_type)
            widget = queryAdapter(mfile, IMediaPlayer, mime_type)

            info_dict = media_info()
            if widget:
                info_dict['widget'] = widget(None, None)
            items.append(info_dict)

        return items

class MediaContainerView(object):
    """ Media Container View
    """

    def __init__(self, context, request):
        self.context = context
        self.request = request

    def media_items(self, media_type=None):
        """ Media items
        """
        provider = IMediaProvider(self.context)
        provider.media_type = media_type

        videos = []
        for mfile in provider.media_items:
            videos.append(mfile)

        return videos

==> eea.mediacentre-6.3.zip: eea.mediacentre-6.3/src/eea/mediacentre/browser/provider.py <==
""" Provider
"""
from zope.component import queryAdapter
from eea.mediacentre.interfaces import IMediaProvider
from eea.mediacentre.interfaces import IMediaDisplayInfo
from eea.mediacentre.interfaces import IMediaPlayer

class MediaContainerVideos(object):
    """ Media Container Videos
    """

    def __init__(self, context, request):
        self.context = context
        self.request = request

    def media_items(self, media_type):
        """ Returns dicts of all media items available.
            media_type arg is a string, e.g. 'video'
        """

        provider = IMediaProvider(self.context)
        provider.media_type = media_type

        items = []
        for mfile in provider.media_items:
            mime_type = mfile.get_content_type()
            media_info = queryAdapter(mfile, IMediaDisplayInfo, mime_type)
            widget = queryAdapter(mfile, IMediaPlayer, mime_type)

            info_dict = media_info()
            if widget:
                info_dict['widget'] = widget(None, None)
            items.append(info_dict)

        return items


class MediaContainerView(object):
    """ Media Container View
    """

    def __init__(self, context, request):
        self.context = context
        self.request = request

    def media_items(self, media_type=None):
        """ Media items
        """
        provider = IMediaProvider(self.context)
        provider.media_type = media_type

        videos = []
        for mfile in provider.media_items:
            videos.append(mfile)

        return videos
